
College Board Celebrity Lab
=====================================

.. |Celebrity Lab| raw:: html

   <a href="https://apcentral.collegeboard.org/pdf/ap-computer-science-a-celebrity-lab-student-guide.pdf" target="_blank" style="text-decoration:underline">Celebrity Lab</a>

The new AP CSA |Celebrity Lab| Activity 4 and 5 involve inheritance. The teacher guide and the code files are available in the AP Course Audit Portal. This page will eventually include tips to complete the labs.
